@@ -12,19 +12,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import TYPE_CHECKING, TypeVar, Union
-
-from selenium import webdriver
+from typing import TypeVar
 
 from appium.common.helper import extract_const_attributes
 from appium.common.logger import logger
+from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
 from appium.webdriver.mobilecommand import MobileCommand as Command
 
-if TYPE_CHECKING:
-    # noinspection PyUnresolvedReferences
-    from appium.webdriver.webdriver import WebDriver
-
-T = TypeVar('T', bound=Union['WebDriver', 'Network'])
+T = TypeVar('T', bound=CanExecuteCommands)
 
 
 class NetSpeed:
@@ -39,10 +34,9 @@ class NetSpeed:
     FULL = 'full'  # No limit, the default (up: 0.0, down: 0.0)
 
 
-class Network(webdriver.Remote):
-
+class Network(CanExecuteCommands):
     @property
-    def network_connection(self: T) -> int:
+    def network_connection(self) -> int:
         """Returns an integer bitmask specifying the network connection type.
 
         Android only.
@@ -50,7 +44,7 @@ class Network(webdriver.Remote):
         """
         return self.execute(Command.GET_NETWORK_CONNECTION, {})['value']
 
-    def set_network_connection(self: T, connection_type: int) -> int:
+    def set_network_connection(self, connection_type: int) -> int:
         """Sets the network connection type. Android only.
 
         Possible values:
@@ -77,11 +71,7 @@ class Network(webdriver.Remote):
         Return:
             int: Set network connection type
         """
-        data = {
-            'parameters': {
-                'type': connection_type
-            }
-        }
+        data = {'parameters': {'type': connection_type}}
         return self.execute(Command.SET_NETWORK_CONNECTION, data)['value']
 
     def toggle_wifi(self: T) -> T:
@@ -112,19 +102,25 @@ class Network(webdriver.Remote):
         if speed_type not in constants.values():
             logger.warning(
                 f'{speed_type} is unknown. Consider using one of {list(constants.keys())} constants. '
-                f'(e.g. {NetSpeed.__name__}.LTE)')
+                f'(e.g. {NetSpeed.__name__}.LTE)'
+            )
 
         self.execute(Command.SET_NETWORK_SPEED, {'netspeed': speed_type})
         return self
 
-    # pylint: disable=protected-access
-    # noinspection PyProtectedMember
-    def _addCommands(self) -> None:
-        self.command_executor._commands[Command.TOGGLE_WIFI] = \
-            ('POST', '/session/$sessionId/appium/device/toggle_wifi')
-        self.command_executor._commands[Command.GET_NETWORK_CONNECTION] = \
-            ('GET', '/session/$sessionId/network_connection')
-        self.command_executor._commands[Command.SET_NETWORK_CONNECTION] = \
-            ('POST', '/session/$sessionId/network_connection')
-        self.command_executor._commands[Command.SET_NETWORK_SPEED] = \
-            ('POST', '/session/$sessionId/appium/device/network_speed')
+    def _add_commands(self) -> None:
+        # noinspection PyProtectedMember,PyUnresolvedReferences
+        commands = self.command_executor._commands
+        commands[Command.TOGGLE_WIFI] = ('POST', '/session/$sessionId/appium/device/toggle_wifi')
+        commands[Command.GET_NETWORK_CONNECTION] = (
+            'GET',
+            '/session/$sessionId/network_connection',
+        )
+        commands[Command.SET_NETWORK_CONNECTION] = (
+            'POST',
+            '/session/$sessionId/network_connection',
+        )
+        commands[Command.SET_NETWORK_SPEED] = (
+            'POST',
+            '/session/$sessionId/appium/device/network_speed',
+        )
