@@ -12,22 +12,25 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import TYPE_CHECKING, Optional
+from typing import Optional, TypeVar
 
 from selenium.webdriver.remote.switch_to import SwitchTo
 
+from appium.protocols.protocol import Protocol
 from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
 
 from .mobilecommand import MobileCommand
 
-if TYPE_CHECKING:
-    from appium.webdriver.webdriver import WebDriver
 
-
-class MobileSwitchTo(SwitchTo):
+class HasDriver(Protocol):
     _driver: CanExecuteCommands
 
-    def context(self, context_name: Optional[str]) -> 'WebDriver':
+
+T = TypeVar('T', bound=HasDriver)
+
+
+class MobileSwitchTo(SwitchTo, HasDriver):
+    def context(self: T, context_name: Optional[str]) -> T:
         """Sets the context for the current session.
         Passing `None` is equal to switching to native context.
 
@@ -38,5 +41,4 @@ class MobileSwitchTo(SwitchTo):
             driver.switch_to.context('WEBVIEW_1')
         """
         self._driver.execute(MobileCommand.SWITCH_TO_CONTEXT, {'name': context_name})
-        # noinspection PyTypeChecker
         return self
